pygeodesy.heights.HeightLinear

Package pygeodesy :: Module heights :: Class HeightLinear |
[frames] | no frames]

# Class HeightLinear

      object --+
               |
    named._Named --+
                   |
        _HeightNamed --+
                       |
             _HeightBase --+
                           |
                 HeightCubic --+
                               |
                              HeightLinear

Height interpolator based on `SciPy` interp2d `kind='linear'` or bisplrep/-ev `kx=ky=1`.

Instance Methods
__init__(self, knots, **name_wrap) New HeightLinear interpolator. |
__call__(self, *llis, **wrap) Interpolate the height for one or several locations. |
height(self, lats, lons, **wrap) Interpolate the height for one or several lat-/longitudes. |
Inherited from `_HeightNamed`: `height_` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_HeightBase`: `numpy`, `scipy`, `scipy_interpolate` Inherited from `_HeightNamed`: `datum`, `kmin`, `wrap` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, knots, **name_wrap) (Constructor) |
New HeightLinear interpolator. Arguments: `knots` - The points with known height (`LatLon`s). `name_wrap` - Optional `name=NN` for this height interpolator (`str`) and keyword argument `b{wrap}=False` to wrap or normalize all `knots` and `llis` locations iff `True` (`bool`). Raises: `HeightError` - Insufficient number of `knots` or invalid `knot`. `ImportError` - Package `numpy` or `scipy` not found or not installed. `SciPyError` - A `scipy` issue. `SciPyWarning` - A `scipy` warning as exception. Overrides: object.__init__ See Also: Here for all details.

### __call__ (self, *llis, **wrap) (Call operator) |
Interpolate the height for one or several locations. Arguments: `llis` - One or more locations (each `LatLon`), all positional. `wrap` - If `wrap=True` to wrap or normalize all `llis` locations (`bool`), overriding the `knots`' setting. Returns: A single interpolated height (`float`) or a list or tuple of interpolated heights (each `float`). Raises: `HeightError` - Insufficient number of `llis` or an invalid `lli`. `SciPyError` - A `scipy` issue. `SciPyWarning` - A `scipy` warning as exception. Overrides: _HeightNamed.__call__ See Also: Here for further details.

### height (self, lats, lons, **wrap) |
Interpolate the height for one or several lat-/longitudes. Arguments: `lats` - Latitude or latitudes (each `degrees`). `lons` - Longitude or longitudes (each `degrees`). `wrap` - Kewyord argument `wrap=False` (`bool`). Use `True` to wrap or normalize all `lats` and `lons` locationts, overriding the `knots`' setting. Returns: A single interpolated height (`float`) or a list of interpolated heights (each `float`). Raises: `HeightError` - Insufficient or unequal number of `lats` and `lons`. `SciPyError` - A `scipy` issue. `SciPyWarning` - A `scipy` warning as exception. Overrides: _HeightNamed.height